@@ -1,12 +1,13 @@
 """
 Application Workflow
 """
-from typing import Callable
+from typing import Optional
 
 from . import exceptions
-from .datastructures import WorkflowContext
+from .datastructures import WorkflowContext, Navigable, Branches
 from .functions import extract_inputs
 from .nodes import (
+    Node,
     step,
     Step,
     SetVar,
@@ -20,20 +21,27 @@ from .nodes import (
 )
 
 
-class Nodes:
+class Nodes(Navigable):
     """
     A series of nodes to be executed on call.
     """
 
     __slots__ = ("_nodes",)
 
-    def __init__(self, *nodes_):
+    def __init__(self, *nodes_: Node):
         self._nodes = list(nodes_)
 
     def __call__(self, context: WorkflowContext):
         with context:
             self._execute(context)
 
+    @property
+    def name(self):
+        return "Nodes"
+
+    def branches(self) -> Optional[Branches]:
+        return {"": self._nodes}
+
     def _execute(self, context: WorkflowContext):
         for node in self._nodes:
             node(context)
@@ -48,20 +56,21 @@ class Workflow(Nodes):
         workflow.
     """
 
-    __slots__ = ("name", "description")
+    __slots__ = ("_name", "description")
 
     def __init__(self, name: str, description: str = None):
         super().__init__()
-        self.name = name
+        self._name = name
         self.description = description
 
     def __call__(self, context: WorkflowContext):
-        context.info("⏩ Workflow: `%s`", self.name)
+        context.info("⏩ Workflow: `%s`", self._name)
         with context:
             self._execute(context)
 
-    def __str__(self):
-        return self.name
+    @property
+    def name(self):
+        return self._name
 
     def execute(
         self, context: WorkflowContext = None, **context_vars
@@ -76,11 +85,11 @@ class Workflow(Nodes):
         """
         context = context or WorkflowContext()
         context.state.update(context_vars)
-        context.logger.info("⏩ Workflow: `%s`", self.name)
+        context.logger.info("⏩ Workflow: `%s`", self._name)
         self._execute(context)
         return context
 
-    def nodes(self, *nodes_: Callable) -> "Workflow":
+    def nodes(self, *nodes_: Node) -> "Workflow":
         """
         Append additional node(s) into the node list
 
@@ -91,7 +100,7 @@ class Workflow(Nodes):
         self._nodes.extend(nodes_)
         return self
 
-    def nested(self, *nodes_: Callable) -> "Workflow":
+    def nested(self, *nodes_: Node) -> "Workflow":
         """
         Add nested node(s), nested nodes have their own scope
 
